@@ -1,5 +1,5 @@
 #
-# $Id: Escape.pm,v 3.13 1999/03/20 07:34:08 gisle Exp $
+# $Id: Escape.pm,v 3.18 2001/05/15 03:41:38 gisle Exp $
 #
 
 package URI::Escape;
@@ -19,14 +19,15 @@ URI::Escape - Escape and unescape unsafe characters
 =head1 DESCRIPTION
 
 This module provides functions to escape and unescape URI strings as
-defined by RFC 2396.  URIs consist of a restricted set of characters,
+defined by RFC 2396 (and updated by RFC 2732).
+URIs consist of a restricted set of characters,
 denoted as C<uric> in RFC 2396.  The restricted set of characters
 consists of digits, letters, and a few graphic symbols chosen from
 those common to most of the character encodings and input facilities
 available to Internet users:
 
   "A" .. "Z", "a" .. "z", "0" .. "9",
-  ";", "/", "?", ":", "@", "&", "=", "+", "$", ",",   # reserved
+  ";", "/", "?", ":", "@", "&", "=", "+", "$", ",", "[", "]",   # reserved
   "-", "_", ".", "!", "~", "*", "'", "(", ")"
 
 In addition any byte (octet) can be represented in a URI by an escape
@@ -60,7 +61,7 @@ character class (between [ ]).  E.g.:
 The default set of characters to be escaped is all those which are
 I<not> part of the C<uric> character class shown above.
 
-=item uri_unescape($string)
+=item uri_unescape($string,...)
 
 Returns a string with all %XX sequences replaced with the actual byte
 (octet).
@@ -79,6 +80,9 @@ where unescaped and something like 700% slowdown if none where.  If
 you are going to unescape a lot of times it might be a good idea to
 inline the RE.
 
+If the uri_unescape() function is passed multiple strings, then each
+one is unescaped returned.
+
 =back
 
 The module can also export the C<%escapes> hash which contains the
@@ -93,7 +97,7 @@ L<URI>
 
 =head1 COPYRIGHT
 
-Copyright 1995-1998 Gisle Aas.
+Copyright 1995-2001 Gisle Aas.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
@@ -107,7 +111,7 @@ require Exporter;
 @ISA = qw(Exporter);
 @EXPORT = qw(uri_escape uri_unescape);
 @EXPORT_OK = qw(%escapes);
-$VERSION = sprintf("%d.%02d", q$Revision: 3.13 $ =~ /(\d+)\.(\d+)/);
+$VERSION = sprintf("%d.%02d", q$Revision: 3.18 $ =~ /(\d+)\.(\d+)/);
 
 use Carp ();
 
@@ -125,14 +129,15 @@ sub uri_escape
     if (defined $patn){
 	unless (exists  $subst{$patn}) {
 	    # Because we can't compile the regex we fake it with a cached sub
+	    (my $tmp = $patn) =~ s,/,\\/,g;
 	    $subst{$patn} =
-	      eval "sub {\$_[0] =~ s/([$patn])/\$escapes{\$1}/g; }";
+	      eval "sub {\$_[0] =~ s/([$tmp])/\$escapes{\$1}/g; }";
 	    Carp::croak("uri_escape: $@") if $@;
 	}
 	&{$subst{$patn}}($text);
     } else {
-	# Default unsafe characters. (RFC 2396 ^uric)
-	$text =~ s/([^;\/?:@&=+\$,A-Za-z0-9\-_.!~*'()])/$escapes{$1}/g;
+	# Default unsafe characters. (RFC 2732 ^uric)
+	$text =~ s/([^;\/?:@&=+\$,A-Za-z0-9\-_.!~*'()[\]])/$escapes{$1}/g;
     }
     $text;
 }
@@ -145,8 +150,11 @@ sub uri_unescape
     my $str = shift;
     if (@_ && wantarray) {
 	# not executed for the common case of a single argument
-	my @str = @_;  # need to copy
-	return map { s/%([0-9A-Fa-f]{2})/chr(hex($1))/eg } $str, @str;
+	my @str = ($str, @_);  # need to copy
+	foreach (@str) {
+	  s/%([0-9A-Fa-f]{2})/chr(hex($1))/eg
+	}
+	return @str;
     }
     $str =~ s/%([0-9A-Fa-f]{2})/chr(hex($1))/eg;
     $str;
